@@ -1,5 +1,5 @@
 /*  SMTUBE2, a small YouTube browser for SMPlayer
-    Copyright (C) 2015-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2015-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,6 +26,10 @@
 #include "retrieveyoutubeurl.h"
 #include "playerdialog.h"
 
+#ifdef USE_SITES
+#include "sitedialog.h"
+#endif
+
 #if QT_VERSION >= 0x050000
 #include "myscroller.h"
 #endif
@@ -51,14 +55,18 @@ ConfigDialog::ConfigDialog(QWidget * parent, Qt::WindowFlags f)
 	MyScroller::setScroller(table);
 	#endif
 #else
-	tabs->setTabEnabled(1, false);
+	tabs->removeTab(find_tab("players_tab"));
 #endif
 
+#ifdef SELECT_RESOLUTION
 	playback_resolution_combo->addItem( "240p", RetrieveYoutubeUrl::R240p );
 	playback_resolution_combo->addItem( "360p", RetrieveYoutubeUrl::R360p );
 	playback_resolution_combo->addItem( "480p", RetrieveYoutubeUrl::R480p );
 	playback_resolution_combo->addItem( "720p", RetrieveYoutubeUrl::R720p );
 	playback_resolution_combo->addItem( "1080p", RetrieveYoutubeUrl::R1080p );
+#else
+	playback_group->hide();
+#endif
 
 #ifdef D_BUTTON
 	external_download_combo->addItem("http://9xbuddy.com/download?url=%YT_URL%");
@@ -77,11 +85,43 @@ ConfigDialog::ConfigDialog(QWidget * parent, Qt::WindowFlags f)
 	style_label->hide();
 	style_combo->hide();
 #endif
+
+#ifndef USE_SITES
+	sites_group->hide();
+#endif
+
+#ifndef USE_YT_DL
+	youtube_app_group->hide();
+#endif
+
+#ifndef FONT_CHANGE
+	font_label->hide();
+	default_font_edit->hide();
+	change_font_button->hide();
+#endif
+
+#if !defined(SELECT_RESOLUTION) && !defined(D_BUTTON) && !defined(USE_SITES)
+	tabs->removeTab(find_tab("general_tab"));
+#endif
+
+#if !defined(STYLE_SWITCHING) && !defined(FONT_CHANGE)
+	tabs->removeTab(find_tab("interface_tab"));
+#endif
 }
 
 ConfigDialog::~ConfigDialog() {
 }
 
+int ConfigDialog::find_tab(const QString & object_name) {
+	for (int n = 0; n < tabs->count(); n++) {
+		if (tabs->widget(n)->objectName() == object_name) {
+			return n;
+		}
+	}
+	return -1;
+}
+
+#ifdef SELECT_RESOLUTION
 void ConfigDialog::setPlaybackResolution(int resolution) {
 	playback_resolution_combo->setCurrentIndex(playback_resolution_combo->findData(resolution));
 }
@@ -90,6 +130,7 @@ int ConfigDialog::playbackResolution() {
 	int index = playback_resolution_combo->currentIndex();
 	return playback_resolution_combo->itemData(index).toInt();
 }
+#endif
 
 #ifdef D_BUTTON
 void ConfigDialog::setAddDownloadButton(bool b) {
@@ -116,6 +157,80 @@ QString ConfigDialog::externalDownloadUrl() {
 }
 #endif
 
+#ifdef USE_SITES
+void ConfigDialog::setSites(QList<Site> list) {
+	site_list = list;
+	refreshSitesCombo();
+}
+
+void ConfigDialog::refreshSitesCombo() {
+	QString current = sites_combo->currentText();
+	sites_combo->clear();
+	for (int n = 0; n < site_list.count(); n++) {
+		if (site_list[n].isVisible()) {
+			sites_combo->addItem(site_list[n].name());
+		}
+	}
+	setCurrentSite(current);
+
+	delete_site_button->setEnabled(sites_combo->count() > 1);
+}
+
+void ConfigDialog::setCurrentSite(const QString & name) {
+	int index = sites_combo->findText(name);
+	if (index == -1) index = 0;
+	sites_combo->setCurrentIndex(index);
+}
+
+QString ConfigDialog::currentSite() {
+	return sites_combo->currentText();
+}
+
+int ConfigDialog::find_site(const QString & name) {
+	for (int n = 0; n < site_list.count(); n++) {
+		if (site_list[n].name() == name) {
+			return n;
+		}
+	}
+	return -1;
+}
+
+void ConfigDialog::on_edit_site_button_clicked() {
+	qDebug("ConfigDialog::on_edit_site_button_clicked");
+
+	int index = find_site(sites_combo->currentText());
+	if (index != -1) {
+		SiteDialog d(this);
+		d.setSite(site_list[index]);
+
+		if (d.exec() == QDialog::Accepted) {
+			site_list[index] = d.site();
+			refreshSitesCombo();
+		}
+	}
+}
+
+void ConfigDialog::on_add_site_button_clicked() {
+	qDebug("ConfigDialog::on_add_site_button_clicked");
+
+	SiteDialog d(this);
+	if (d.exec() == QDialog::Accepted) {
+		site_list << d.site();
+		refreshSitesCombo();
+	}
+}
+
+void ConfigDialog::on_delete_site_button_clicked() {
+	qDebug("ConfigDialog::on_delete_site_button_clicked");
+
+	if (sites_combo->count() > 1) {
+		int index = find_site(sites_combo->currentText());
+		if (index != -1) site_list[index].setVisible(false);
+		refreshSitesCombo();
+	}
+}
+#endif
+
 #ifdef USE_PLAYERS
 void ConfigDialog::setPlayers(QList<Player> list) {
 	qDebug() << "ConfigDialog::setPlayers:" << list.count();
@@ -288,6 +403,7 @@ void ConfigDialog::updateAddPlayersButton() {
 }
 #endif
 
+#ifdef FONT_CHANGE
 void ConfigDialog::setDefaultFont(const QFont & f) {
 	default_font_edit->setText(f.toString());
 }
@@ -297,6 +413,7 @@ QFont ConfigDialog::defaultFont() {
 	f.fromString(default_font_edit->text());
 	return f;
 }
+#endif
 
 #ifdef STYLE_SWITCHING
 void ConfigDialog::setStyle(const QString & style) {
@@ -319,6 +436,7 @@ QString ConfigDialog::style() {
 }
 #endif
 
+#ifdef FONT_CHANGE
 void ConfigDialog::on_change_font_button_clicked() {
 	QFont f = qApp->font();
 
@@ -333,5 +451,42 @@ void ConfigDialog::on_change_font_button_clicked() {
 		default_font_edit->setText( f.toString() );
 	}
 }
+#endif
+
+#ifdef USE_YT_DL
+void ConfigDialog::setYtdlBin(const QString & path) {
+	ytdl_bin_combo->clear();
+	ytdl_bin_combo->addItem("youtube-dl", "youtube-dl");
+	ytdl_bin_combo->addItem(tr("yt-dlp (based on youtube-dl with improvements)"), "yt-dlp");
+
+	QString ytdl_bin = path;
+	if (ytdl_bin.isEmpty()) ytdl_bin = YTDL_DEFAULT_BIN;
+	QString basename = QFileInfo(ytdl_bin).baseName();
+
+	int selected = 0;
+	if (basename == "youtube-dl") {
+		selected = 0;
+		ytdl_bin_combo->setItemData(0, path);
+	}
+	else
+	if (basename == "yt-dlp") {
+		selected = 1;
+		ytdl_bin_combo->setItemData(1, path);
+	}
+	else {
+		selected = 2;
+		ytdl_bin_combo->addItem(tr("Other") + " (" + basename + ")", path);
+	}
+
+	ytdl_bin_combo->setCurrentIndex(selected);
+}
+
+QString ConfigDialog::ytdlBin() {
+	QString ytdl_bin = ytdl_bin_combo->itemData(ytdl_bin_combo->currentIndex()).toString();
+	if (ytdl_bin == YTDL_DEFAULT_BIN) ytdl_bin = ""; // Default
+	return ytdl_bin;
+}
+
+#endif
 
 #include "moc_configdialog.cpp"
