@@ -1,5 +1,5 @@
 /*  smtube, a small youtube browser.
-    Copyright (C) 2012-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2012-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,14 +23,15 @@
 #include <QDir>
 #include <QSettings>
 #include <QDebug>
+#include "qtcompat.h"
 
 //#define D_PLAYERS
 //#define DEBUG_FIND_EX
 
-#ifdef Q_OS_LINUX
+#ifdef OS_UNIX_NOT_MAC
 QString Player::findExecutable(const QString & name) {
 	QByteArray env = qgetenv("PATH");
-	QStringList search_paths = QString::fromLocal8Bit(env.constData()).split(':', QString::SkipEmptyParts);
+	QStringList search_paths = QString::fromLocal8Bit(env.constData()).split(':', QTC_SkipEmptyParts);
 	for (int n = 0; n < search_paths.count(); n++) {
 		QString candidate = search_paths[n] + "/" + name;
 		#ifdef DEBUG_FIND_EX
@@ -44,7 +45,7 @@ QString Player::findExecutable(const QString & name) {
 			return candidate;
 		}
 	}
-	return QString::null;
+	return QString();
 }
 #endif
 
@@ -80,7 +81,7 @@ QString Player::executable(bool * found) {
 		#endif
 	}
 
-#ifdef Q_OS_LINUX
+#ifdef OS_UNIX_NOT_MAC
 	bin = findExecutable(player_bin);
 	if (!bin.isEmpty()) {
 		if (found) *found = true;
@@ -101,29 +102,22 @@ QString Player::executable(bool * found) {
 
 Players::Players() {
 #ifdef Q_OS_WIN
-	list.push_back( Player("SMPlayer", "smplayer.exe", "%u", true, true, Player::Video) );
-	list.push_back( Player("SMPlayer (audio)", "smplayer.exe", "%u -media-title %t", true, false, Player::Audio) );
-	list.push_back( Player("SMPlayer (add to playlist)", "smplayer.exe", "-add-to-playlist %u", true, true, Player::VideoAudio) );
-	/*
-	list.push_back( Player("VLC", "C:\\Program Files\\VideoLAN\\VLC\\vlc.exe", "%u --meta-title=%t", false) );
-	*/
-	#ifdef D_PLAYERS
-	//list.push_back( Player("yoDownet", "yoDownet.exe", "%u -o %f", false, false, Player::VideoAudio) );
-	#endif
+	list << Player("SMPlayer", "smplayer.exe", "%u", true, true, Player::Video)
+		 << Player("SMPlayer (audio)", "smplayer.exe", "%u -media-title %t", true, false, Player::Audio)
+		 << Player("SMPlayer (add to playlist)", "smplayer.exe", "-add-to-playlist %u", true, true, Player::VideoAudio);
 #else
-	list.push_back( Player("SMPlayer", "smplayer", "%u", true, true, Player::Video) );
-	list.push_back( Player("SMPlayer (audio)", "smplayer", "%u -media-title %t", true, false, Player::Audio) );
-	list.push_back( Player("SMPlayer (add to playlist)", "smplayer", "-add-to-playlist %u", true, true, Player::VideoAudio) );
-	list.push_back( Player("MPlayer", "mplayer", "%u -title %t", false, false, Player::Video) );
-	list.push_back( Player("VLC", "vlc", "%u --meta-title=%t", false, true, Player::VideoAudio) );
-	list.push_back( Player("Dragon Player", "dragon", "%u", false, false, Player::VideoAudio) );
-	list.push_back( Player("Totem", "totem", "%u", false, false, Player::VideoAudio) );
-	list.push_back( Player("GNOME-MPlayer", "gnome-mplayer", "%u", false, false, Player::VideoAudio) );
-	list.push_back( Player("mpv", "mpv", "%u --title=%t", false, true, Player::Video) );
-	list.push_back( Player("mpv + youtube-dl", "mpv", "--ytdl --ytdl-format=best %u", true, true, Player::Video) );
+	list << Player("SMPlayer", "smplayer", "%u", true, true, Player::Video)
+		 << Player("SMPlayer (audio)", "smplayer", "%u -media-title %t", true, false, Player::Audio)
+		 << Player("SMPlayer (add to playlist)", "smplayer", "-add-to-playlist %u", true, true, Player::VideoAudio)
+		 << Player("MPlayer", "mplayer", "%u -title %t", false, false, Player::Video)
+		 << Player("VLC", "vlc", "%u --meta-title=%t", false, true, Player::VideoAudio)
+		 << Player("Dragon Player", "dragon", "%u", false, false, Player::VideoAudio)
+		 << Player("Totem", "totem", "%u", false, false, Player::VideoAudio)
+		 << Player("GNOME-MPlayer", "gnome-mplayer", "%u", false, false, Player::VideoAudio)
+		 << Player("mpv", "mpv", "%u --title=%t", false, true, Player::Video)
+		 << Player("mpv + youtube-dl", "mpv", "--ytdl --ytdl-format=best %u", true, true, Player::Video);
 	#ifdef D_PLAYERS
-	list.push_back( Player("uget", "uget-gtk", "--quiet --folder=/tmp --filename=%f %u", false, false, Player::VideoAudio) );
-	//list.push_back( Player("yoDownet", "yoDownet", "%u -o %f", false, false, Player::VideoAudio) );
+	list << Player("uget", "uget-gtk", "--quiet --folder=/tmp --filename=%f %u", false, false, Player::VideoAudio);
 	#endif
 #endif
 	default_list = list;
