@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="es">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.0">
 <context>
     <name>About</name>
     <message>
@@ -11,7 +9,7 @@
     <message>
         <location filename="../about.ui" line="33"/>
         <source>&amp;Info</source>
-        <translation>&amp;Info</translation>
+        <translation>&amp;Información</translation>
     </message>
     <message>
         <location filename="../about.ui" line="89"/>
@@ -26,7 +24,7 @@
     <message>
         <location filename="../about.cpp" line="34"/>
         <source>YouTube%1 Browser for SMPlayer</source>
-        <translation>Buscador de vídeos de YouTube%1 de SMPlayer</translation>
+        <translation>Navegador de YouTube%1 de SMPlayer</translation>
     </message>
     <message>
         <location filename="../about.cpp" line="37"/>
@@ -36,7 +34,7 @@
     <message>
         <location filename="../about.cpp" line="39"/>
         <source>Portable Edition</source>
-        <translation>Edición Portable</translation>
+        <translation>Edición portable</translation>
     </message>
     <message>
         <location filename="../about.cpp" line="42"/>
@@ -46,7 +44,7 @@
     <message>
         <location filename="../about.cpp" line="44"/>
         <source>Visit our website for updates:</source>
-        <translation>Visita nuestra web para conseguir actualizaciones:</translation>
+        <translation>Visite nuestra web para conseguir actualizaciones:</translation>
     </message>
     <message>
         <location filename="../about.cpp" line="87"/>
@@ -56,17 +54,17 @@
     <message>
         <location filename="../about.cpp" line="88"/>
         <source>You can also help to translate SMTube into your own language.</source>
-        <translation>Tú también puedes ayudar a traducir el SMTube a tu propio idioma.</translation>
+        <translation>También puede ayudar a traducir SMTube a su propio idioma.</translation>
     </message>
     <message>
         <location filename="../about.cpp" line="89"/>
         <source>Visit %1 and join a translation team.</source>
-        <translation>Visita %1 y únete a un equipo de traducción.</translation>
+        <translation>Visite %1 y únase a un equipo de traducción.</translation>
     </message>
     <message>
         <location filename="../about.cpp" line="91"/>
         <source>Click here to know the translators from the transifex teams</source>
-        <translation>Pulsa aquí para conocer los traductores de los equipos de transifex</translation>
+        <translation>Haga clic aquí para conocer a los traductores de los equipos de Transifex</translation>
     </message>
     <message>
         <location filename="../about.cpp" line="117"/>
@@ -77,169 +75,107 @@
 <context>
     <name>BrowserWindow</name>
     <message>
-        <location filename="../browserwindow.cpp" line="125"/>
+        <location filename="../browserwindow.cpp" line="138"/>
         <source>Home</source>
         <translation>Inicio</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="128"/>
+        <location filename="../browserwindow.cpp" line="141"/>
         <source>Navigation</source>
         <translation>Navegación</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="136"/>
+        <location filename="../browserwindow.cpp" line="149"/>
         <source>Zoom +</source>
-        <translation>Zoom +</translation>
+        <translation>Ampliar</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="140"/>
+        <location filename="../browserwindow.cpp" line="153"/>
         <source>Zoom -</source>
-        <translation>Zoom -</translation>
+        <translation>Reducir</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="144"/>
+        <location filename="../browserwindow.cpp" line="157"/>
         <source>&amp;Quit</source>
         <translation>&amp;Salir</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="147"/>
+        <location filename="../browserwindow.cpp" line="160"/>
         <source>&amp;Navigation</source>
         <translation>&amp;Navegación</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="159"/>
+        <location filename="../browserwindow.cpp" line="172"/>
         <source>&amp;View</source>
         <translation>&amp;Ver</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="160"/>
+        <location filename="../browserwindow.cpp" line="173"/>
         <source>Toolbar</source>
         <translation>Barra de herramientas</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="164"/>
+        <location filename="../browserwindow.cpp" line="177"/>
         <source>Statusbar</source>
         <translation>Barra de estado</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="168"/>
+        <location filename="../browserwindow.cpp" line="182"/>
         <source>&amp;Settings</source>
         <translation>&amp;Configuración</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="176"/>
+        <location filename="../browserwindow.cpp" line="194"/>
         <source>&amp;Help</source>
         <translation>&amp;Ayuda</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="179"/>
-        <source>&amp;Update the YouTube code</source>
-        <translation>Actualizar el código de &amp;YouTube</translation>
+        <location filename="../browserwindow.cpp" line="198"/>
+        <source>&amp;Update YouTube playback support</source>
+        <translation>Actualizar el código para reproducir vídeos de &amp;YouTube</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="185"/>
-        <source>About this &amp;release</source>
-        <translation>Acerca de esta &amp;version</translation>
+        <location filename="../browserwindow.cpp" line="200"/>
+        <source>&amp;Install / Update YouTube playback support</source>
+        <translation>&amp;Instalar/actualizar el código para reproducir vídeos de YouTube</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="190"/>
+        <location filename="../browserwindow.cpp" line="206"/>
         <source>&amp;About SMTube</source>
         <translation>&amp;Acerca de SMTube</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="298"/>
+        <location filename="../browserwindow.cpp" line="331"/>
         <source>Download video using an external service</source>
         <translation>Descargar el vídeo usando un servicio externo</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="299"/>
+        <location filename="../browserwindow.cpp" line="332"/>
         <source>Download</source>
         <translation>Descargar</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="501"/>
-        <source>Connection failed</source>
-        <translation>Error en la conexión</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="502"/>
-        <source>The video you requested needs to open a HTTPS connection.</source>
-        <translation>El vídeo que has solicitado necesita abrir una conexión HTTPS.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="503"/>
-        <source>Unfortunately the OpenSSL component, required for it, is not available in your system.</source>
-        <translation>Lamentablemente el componente OpenSSL, que es necesario para ello, no se encuentra en tu sistema.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="508"/>
+        <location filename="../browserwindow.cpp" line="578"/>
         <source>No video found</source>
-        <translation>No se ha encontrado el vídeo</translation>
+        <translation>No se ha encontrado ningún vídeo</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="509"/>
+        <location filename="../browserwindow.cpp" line="579"/>
         <source>It wasn&apos;t possible to find the URL for this video.</source>
-        <translation>No ha sido posible encontrar la URL de este vídeo.</translation>
+        <translation>No ha sido posible encontrar el URL de este vídeo.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="519"/>
-        <location filename="../browserwindow.cpp" line="527"/>
-        <source>Problems with YouTube</source>
-        <translation>Problemas con YouTube</translation>
+        <location filename="../browserwindow.cpp" line="610"/>
+        <source>About...</source>
+        <translation>Acerca de...</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="520"/>
-        <location filename="../browserwindow.cpp" line="528"/>
-        <source>Unfortunately due to changes in YouTube, the video &apos;%1&apos; can&apos;t be played.</source>
-        <translation>Lamentablemente debido a cambios en YouTube, no es posible reproducir el vídeo &apos;%1&apos;.</translation>
+        <location filename="../browserwindow.cpp" line="611"/>
+        <source>YouTube%1 Browser for SMPlayer</source>
+        <translation>Navegador de YouTube%1 de SMPlayer</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="521"/>
-        <source>Do you want to update the YouTube code? This may fix the problem.</source>
-        <translation>¿Quieres actualizar el código de YouTube? Esto podría solucionar el problema.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="529"/>
-        <source>Maybe updating this application could fix the problem.</source>
-        <translation>Quizás el problema se podría solucionar actualizando esta aplicación.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="548"/>
-        <source>About this release</source>
-        <translation>Acerca de esta version</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="549"/>
-        <source>Due to changes in YouTube, the old SMTube doesn&apos;t work anymore.</source>
-        <translation>Debido a cambios en YouTube, la versión anterior de SMTube ha dejado de funcionar.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="550"/>
-        <source>This is a new version of SMTube, written from scratch.</source>
-        <translation>Esta es una versión totalmente nueva, escrita desde cero.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="551"/>
-        <source>Some functionality is not available yet.</source>
-        <translation>Todavía no están disponible todas las funciones.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="553"/>
-        <source>Important:</source>
-        <translation>Importante:</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="554"/>
-        <source>If the VEVO videos fail to play, please use the option %1 in the Help menu.</source>
-        <translation>Si los vídeos VEVO no se reproducen, por favor usa la opción %1 del menú Ayuda.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="555"/>
-        <source>Update the YouTube code</source>
-        <translation>Actualizar el código de YouTube</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="284"/>
+        <location filename="../browserwindow.cpp" line="317"/>
         <source>Loading... %1%</source>
         <translation>Cargando... %1%</translation>
     </message>
@@ -247,45 +183,106 @@
 <context>
     <name>CodeDownloader</name>
     <message>
-        <location filename="../codedownloader.cpp" line="37"/>
+        <location filename="../codedownloader.cpp" line="49"/>
         <source>Downloading...</source>
         <translation>Descargando...</translation>
     </message>
     <message>
-        <location filename="../codedownloader.cpp" line="58"/>
+        <location filename="../codedownloader.cpp" line="76"/>
         <source>Connecting to %1</source>
         <translation>Conectando con %1</translation>
     </message>
     <message>
-        <location filename="../codedownloader.cpp" line="126"/>
-        <source>The Youtube code has been updated successfully.</source>
-        <translation>El código de Youtube se ha actualizado correctamente.</translation>
+        <location filename="../codedownloader.cpp" line="145"/>
+        <source>The YouTube code has been installed successfully.</source>
+        <translation>El código de YouTube se ha instalado correctamente.</translation>
     </message>
     <message>
-        <location filename="../codedownloader.cpp" line="127"/>
+        <location filename="../codedownloader.cpp" line="146"/>
         <source>Installed version: %1</source>
         <translation>Versión instalada: %1</translation>
     </message>
     <message>
-        <location filename="../codedownloader.cpp" line="128"/>
+        <location filename="../codedownloader.cpp" line="147"/>
         <source>Success</source>
-        <translation>Operación realizada correctamente</translation>
+        <translation>Todo correcto</translation>
     </message>
     <message>
-        <location filename="../codedownloader.cpp" line="133"/>
-        <location filename="../codedownloader.cpp" line="138"/>
+        <location filename="../codedownloader.cpp" line="152"/>
+        <location filename="../codedownloader.cpp" line="157"/>
         <source>Error</source>
         <translation>Error</translation>
     </message>
     <message>
-        <location filename="../codedownloader.cpp" line="133"/>
-        <source>An error happened writing %1</source>
-        <translation>Ha ocurrido un error al escribir en %1</translation>
+        <location filename="../codedownloader.cpp" line="152"/>
+        <source>It&apos;s not possible to save %1.</source>
+        <translation>No es posible guardar %1.</translation>
     </message>
     <message>
-        <location filename="../codedownloader.cpp" line="138"/>
+        <location filename="../codedownloader.cpp" line="157"/>
         <source>An error happened while downloading the file:&lt;br&gt;%1</source>
-        <translation>Ha ocurrido un error descargando el fichero:&lt;br&gt;%1</translation>
+        <translation>Se ha producido un error al descargar el archivo::&lt;br&gt;%1</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="165"/>
+        <source>%1 failed to communicate with youtube-dl. Either it&apos;s not installed or it doesn&apos;t work correctly.</source>
+        <translation>%1 no se ha podido comunicar con youtube-dl. O no está instalado o no funciona correctamente.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="169"/>
+        <source>It wasn&apos;t possible to find the URL for this video.</source>
+        <translation>No se ha podido encontrar el URL de este vídeo.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="170"/>
+        <source>Maybe you need to update youtube-dl.</source>
+        <translation>Quizás haya que actualizar youtube-dl.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="175"/>
+        <source>In order to play YouTube videos, %1 needs an external application called youtube-dl.</source>
+        <translation>Para poder reproducir vídeos de YouTube, %1 necesita una aplicación externa llamada youtube-dl.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="176"/>
+        <source>This component needs to be updated frequently.</source>
+        <translation>Hay que actualizar este componente con frecuencia.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="177"/>
+        <source>You can update it just by reinstalling SMPlayer. The installer will download and install the very latest version.</source>
+        <translation>Puede actualizarlo reinstalando SMPlayer. El instalador descargará e instalará la última versión.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="179"/>
+        <source>Install / Update YouTube support</source>
+        <translation>Instalar/actualizar el código de YouTube</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="232"/>
+        <source>In order to play YouTube videos, %1 needs the help of an external application.</source>
+        <translation>Para poder reproducir vídeos de YouTube, %1 necesita la ayuda de una aplicación externa.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="233"/>
+        <source>%1 can download and install this application for you.</source>
+        <translation>%1 puede descargar e instalar esta aplicación.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="234"/>
+        <source>It will be downloaded from the official website and installed as %1.</source>
+        <translation>Se descargará de la web oficial y se instalará en %1.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="235"/>
+        <source>Would you like to proceed?</source>
+        <translation>¿Quieres continuar?</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="239"/>
+        <location filename="../codedownloader.cpp" line="242"/>
+        <source>Install YouTube support?</source>
+        <translation>¿Instalar el código de YouTube?</translation>
     </message>
 </context>
 <context>
@@ -301,17 +298,22 @@
         <translation>&amp;General</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="108"/>
+        <location filename="../configdialog.ui" line="127"/>
+        <source>A&amp;dd...</source>
+        <translation>Aña&amp;dir...</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="178"/>
         <source>&amp;Players</source>
         <translation>&amp;Reproductores</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="156"/>
+        <location filename="../configdialog.ui" line="226"/>
         <source>Add</source>
         <translation>Añadir</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="121"/>
+        <location filename="../configdialog.ui" line="191"/>
         <source>Up</source>
         <translation>Subir</translation>
     </message>
@@ -326,37 +328,62 @@
         <translation>Calidad &amp;preferida:</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="167"/>
-        <source>Delete</source>
-        <translation>Borrar</translation>
+        <location filename="../configdialog.ui" line="94"/>
+        <source>Sites</source>
+        <translation>Sitios web</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="191"/>
+        <location filename="../configdialog.ui" line="100"/>
+        <source>&amp;Site:</source>
+        <translation>&amp;Sitio:</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="120"/>
+        <source>Edi&amp;t...</source>
+        <translation>Edi&amp;tar...</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="138"/>
+        <source>De&amp;lete</source>
+        <translation>E&amp;liminar</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="152"/>
+        <source>YouTube support application</source>
+        <translation>Aplicación para YouTube</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="237"/>
+        <source>Delete</source>
+        <translation>Eliminar</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="261"/>
         <source>Edit</source>
         <translation>Editar</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="204"/>
+        <location filename="../configdialog.ui" line="274"/>
         <source>A&amp;dd predefined players</source>
-        <translation>Añadir &amp;reproductores predeterminados</translation>
+        <translation>Añadir los &amp;reproductores predeterminados</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="240"/>
+        <location filename="../configdialog.ui" line="310"/>
         <source>&amp;Interface</source>
         <translation>&amp;Interfaz</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="248"/>
+        <location filename="../configdialog.ui" line="318"/>
         <source>&amp;Style:</source>
         <translation>&amp;Estilo:</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="284"/>
+        <location filename="../configdialog.ui" line="354"/>
         <source>Font:</source>
         <translation>Tipo de letra:</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="298"/>
+        <location filename="../configdialog.ui" line="368"/>
         <source>C&amp;hange...</source>
         <translation>Ca&amp;mbiar...</translation>
     </message>
@@ -371,71 +398,90 @@
         <translation>Descargar vídeos usando un servicio &amp;externo</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="132"/>
+        <location filename="../configdialog.ui" line="202"/>
         <source>Down</source>
         <translation>Bajar</translation>
     </message>
     <message>
-        <location filename="../configdialog.cpp" line="81"/>
+        <location filename="../configdialog.cpp" line="82"/>
         <source>Default</source>
         <translation>Predeterminado</translation>
     </message>
+    <message>
+        <location filename="../configdialog.cpp" line="460"/>
+        <source>yt-dlp (based on youtube-dl with improvements)</source>
+        <translation>yt-dlp (basada en youtube-dl con mejoras)</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.cpp" line="478"/>
+        <source>Other</source>
+        <translation>Otra</translation>
+    </message>
 </context>
 <context>
     <name>FileChooser</name>
     <message>
         <location filename="../filechooser.cpp" line="56"/>
         <source>Click to select a file or folder</source>
-        <translation>Pulsa para seleccionar un archivo o carpeta</translation>
+        <translation>Haga clic para seleccionar un archivo o una carpeta</translation>
     </message>
 </context>
 <context>
     <name>MyWebView</name>
     <message>
-        <location filename="../mywebview.cpp" line="36"/>
-        <source>Open link in a web browser</source>
-        <translation>Abrir enlace en un navegador web</translation>
-    </message>
-    <message>
-        <location filename="../mywebview.cpp" line="52"/>
-        <source>Open link in new window</source>
-        <translation>Abrir enlace en una nueva ventana</translation>
-    </message>
-    <message>
-        <location filename="../mywebview.cpp" line="75"/>
-        <source>Open audio with</source>
-        <translation>Abrir audio con</translation>
-    </message>
-    <message>
-        <location filename="../mywebview.cpp" line="99"/>
-        <location filename="../mywebview.cpp" line="124"/>
-        <source>Open with %1</source>
-        <translation>Abrir con %1</translation>
-    </message>
-    <message>
-        <location filename="../mywebview.cpp" line="131"/>
-        <source>Open audio with %1</source>
-        <translation>Abrir audio con %1</translation>
-    </message>
-    <message>
-        <location filename="../mywebview.cpp" line="49"/>
-        <source>Copy link to clipboard</source>
-        <translation>Copiar enlace al portapapeles</translation>
+        <location filename="../mywebview.cpp" line="37"/>
+        <source>Open in &amp;YouTube</source>
+        <translation>Abrir en &amp;YouTube</translation>
     </message>
     <message>
         <location filename="../mywebview.cpp" line="48"/>
-        <source>Save link...</source>
-        <translation>Descargar enlace...</translation>
-    </message>
-    <message>
-        <location filename="../mywebview.cpp" line="50"/>
-        <source>Open link in this window</source>
-        <translation>Abrir enlace en esta ventana</translation>
+        <source>&amp;Save link...</source>
+        <translation>&amp;Descargar el enlace...</translation>
     </message>
     <message>
         <location filename="../mywebview.cpp" line="51"/>
-        <source>Copy text to clipboard</source>
-        <translation>Copiar texto al portapapeles</translation>
+        <source>Copy &amp;link to clipboard</source>
+        <translation>Copiar el en&amp;lace al portapapeles</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="52"/>
+        <source>Open link in this window</source>
+        <translation>Abrir el enlace en esta ventana</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="54"/>
+        <source>&amp;Copy text to clipboard</source>
+        <translation>&amp;Copiar el texto al portapapeles</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="55"/>
+        <source>Open link in &amp;new window</source>
+        <translation>Abrir el enlace en una &amp;nueva ventana</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="79"/>
+        <source>&amp;Play with</source>
+        <translation>&amp;Reproducir con</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="84"/>
+        <source>Play &amp;audio with</source>
+        <translation>Reproducir el &amp;audio con</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="137"/>
+        <source>&amp;Play with %1</source>
+        <translation>&amp;Reproducir con %1</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="145"/>
+        <source>Play &amp;audio with %1</source>
+        <translation>Reproducir el &amp;audio con %1</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="154"/>
+        <source>Play video with a &amp;web browser</source>
+        <translation>Reproducir el vídeo en un navegador &amp;web</translation>
     </message>
 </context>
 <context>
@@ -443,7 +489,7 @@
     <message>
         <location filename="../playerdialog.ui" line="14"/>
         <source>Edit Player</source>
-        <translation>Editar Reproductor</translation>
+        <translation>Editar el reproductor</translation>
     </message>
     <message>
         <location filename="../playerdialog.ui" line="22"/>
@@ -463,12 +509,12 @@
     <message>
         <location filename="../playerdialog.ui" line="71"/>
         <source>This player supports &amp;video sites</source>
-        <translation>Este reproductor incorpora soporte para webs de &amp;vídeos</translation>
+        <translation>Este reproductor admite sitios web de &amp;vídeos</translation>
     </message>
     <message>
         <location filename="../playerdialog.ui" line="78"/>
         <source>This player can play &amp;online TV</source>
-        <translation>Este reproductor puede reproducir TV &amp;online</translation>
+        <translation>Este reproductor puede repr&amp;oducir TV en línea</translation>
     </message>
     <message>
         <location filename="../playerdialog.ui" line="87"/>
@@ -483,7 +529,7 @@
     <message>
         <location filename="../playerdialog.cpp" line="28"/>
         <source>None</source>
-        <translation>Ninguno</translation>
+        <translation>Desactivar</translation>
     </message>
     <message>
         <location filename="../playerdialog.cpp" line="29"/>
@@ -506,4 +552,40 @@
         <translation>Predeterminada</translation>
     </message>
 </context>
-</TS>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../version.cpp" line="48"/>
+        <source>%1 (revision %2) %3</source>
+        <translation>%1 (revisión %2) %3</translation>
+    </message>
+    <message>
+        <location filename="../version.cpp" line="50"/>
+        <source>%1 (revision %2)</source>
+        <translation>%1 (revisión %2)</translation>
+    </message>
+</context>
+<context>
+    <name>SiteDialog</name>
+    <message>
+        <location filename="../sitedialog.ui" line="14"/>
+        <source>Edit Site</source>
+        <translation>Editar el sitio web</translation>
+    </message>
+    <message>
+        <location filename="../sitedialog.ui" line="22"/>
+        <source>&amp;Name:</source>
+        <translation>&amp;Nombre:</translation>
+    </message>
+    <message>
+        <location filename="../sitedialog.ui" line="39"/>
+        <source>&amp;Home page URL:</source>
+        <translation>&amp;URL de la página principal:</translation>
+    </message>
+    <message>
+        <location filename="../sitedialog.ui" line="56"/>
+        <source>&amp;Search URL:</source>
+        <translation>URL de la página de &amp;búsqueda:</translation>
+    </message>
+</context>
+</TS>
\ No newline at end of file
