@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="gl">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="gl" version="2.0">
 <context>
     <name>About</name>
     <message>
@@ -77,169 +75,107 @@
 <context>
     <name>BrowserWindow</name>
     <message>
-        <location filename="../browserwindow.cpp" line="125"/>
+        <location filename="../browserwindow.cpp" line="138"/>
         <source>Home</source>
         <translation>Inicio</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="128"/>
+        <location filename="../browserwindow.cpp" line="141"/>
         <source>Navigation</source>
         <translation>Navegación</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="136"/>
+        <location filename="../browserwindow.cpp" line="149"/>
         <source>Zoom +</source>
         <translation>Ampliar</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="140"/>
+        <location filename="../browserwindow.cpp" line="153"/>
         <source>Zoom -</source>
         <translation>Reducir</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="144"/>
+        <location filename="../browserwindow.cpp" line="157"/>
         <source>&amp;Quit</source>
         <translation>&amp;Saír</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="147"/>
+        <location filename="../browserwindow.cpp" line="160"/>
         <source>&amp;Navigation</source>
         <translation>&amp;Navegación</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="159"/>
+        <location filename="../browserwindow.cpp" line="172"/>
         <source>&amp;View</source>
         <translation>&amp;Ver</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="160"/>
+        <location filename="../browserwindow.cpp" line="173"/>
         <source>Toolbar</source>
         <translation>Barra de ferramentas</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="164"/>
+        <location filename="../browserwindow.cpp" line="177"/>
         <source>Statusbar</source>
         <translation>Barra de estado</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="168"/>
+        <location filename="../browserwindow.cpp" line="182"/>
         <source>&amp;Settings</source>
         <translation>&amp;Axstes</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="176"/>
+        <location filename="../browserwindow.cpp" line="194"/>
         <source>&amp;Help</source>
         <translation>A&amp;xuda</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="179"/>
-        <source>&amp;Update the YouTube code</source>
-        <translation>&amp;Actualizar o código de YouTube</translation>
+        <location filename="../browserwindow.cpp" line="198"/>
+        <source>&amp;Update YouTube playback support</source>
+        <translation>&amp;Actualizar compatibilidade con YouTube</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="185"/>
-        <source>About this &amp;release</source>
-        <translation>Sobre esta &amp;publicación</translation>
+        <location filename="../browserwindow.cpp" line="200"/>
+        <source>&amp;Install / Update YouTube playback support</source>
+        <translation>&amp;Instalar / Actualizar compatibilidade para reprodución no YouTube</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="190"/>
+        <location filename="../browserwindow.cpp" line="206"/>
         <source>&amp;About SMTube</source>
         <translation>&amp;Sobre SMTube</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="298"/>
+        <location filename="../browserwindow.cpp" line="331"/>
         <source>Download video using an external service</source>
         <translation>Descargar o vídeo por medio dun servizo externo</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="299"/>
+        <location filename="../browserwindow.cpp" line="332"/>
         <source>Download</source>
         <translation>Descargar</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="501"/>
-        <source>Connection failed</source>
-        <translation>A conexión fallou</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="502"/>
-        <source>The video you requested needs to open a HTTPS connection.</source>
-        <translation>O vídeo solicitado precisa abrir a conexión HTTPS.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="503"/>
-        <source>Unfortunately the OpenSSL component, required for it, is not available in your system.</source>
-        <translation>Desafortunadamente o compoñente OpenSSL requirido non está dispoñíbel no sistema.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="508"/>
+        <location filename="../browserwindow.cpp" line="578"/>
         <source>No video found</source>
         <translation>Non se atopou ningún vídeo</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="509"/>
+        <location filename="../browserwindow.cpp" line="579"/>
         <source>It wasn&apos;t possible to find the URL for this video.</source>
         <translation>Non foi posíbel atopar a URL deste vídeo.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="519"/>
-        <location filename="../browserwindow.cpp" line="527"/>
-        <source>Problems with YouTube</source>
-        <translation>Problemas con YouTube</translation>
+        <location filename="../browserwindow.cpp" line="610"/>
+        <source>About...</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="520"/>
-        <location filename="../browserwindow.cpp" line="528"/>
-        <source>Unfortunately due to changes in YouTube, the video &apos;%1&apos; can&apos;t be played.</source>
-        <translation>Debido a cambios en YouTube non é posíbel reproducir o vídeo %1.</translation>
+        <location filename="../browserwindow.cpp" line="611"/>
+        <source>YouTube%1 Browser for SMPlayer</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="521"/>
-        <source>Do you want to update the YouTube code? This may fix the problem.</source>
-        <translation>Quere actualizar o código de acceso a YouTube? Esta actualización podería solucionar o problema.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="529"/>
-        <source>Maybe updating this application could fix the problem.</source>
-        <translation>Actualizar o programa podeŕia solucionar o problema.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="548"/>
-        <source>About this release</source>
-        <translation>Sobre esta versión</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="549"/>
-        <source>Due to changes in YouTube, the old SMTube doesn&apos;t work anymore.</source>
-        <translation>Debido a cambios en YouTube, a versión vella de SMTube xa non funciona.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="550"/>
-        <source>This is a new version of SMTube, written from scratch.</source>
-        <translation>Esta é unha nova versión de SMTube escrita desde cero.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="551"/>
-        <source>Some functionality is not available yet.</source>
-        <translation>Algunhas funcionalidades aínda non están dispoñíbeis.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="553"/>
-        <source>Important:</source>
-        <translation>Importante:</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="554"/>
-        <source>If the VEVO videos fail to play, please use the option %1 in the Help menu.</source>
-        <translation>Se non consigue reproducir vídeos de VEVO, use a opción «%1» do menú de axuda.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="555"/>
-        <source>Update the YouTube code</source>
-        <translation>Actualizar o código para YouTube</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="284"/>
+        <location filename="../browserwindow.cpp" line="317"/>
         <source>Loading... %1%</source>
         <translation>Cargando... %1%</translation>
     </message>
@@ -247,46 +183,107 @@
 <context>
     <name>CodeDownloader</name>
     <message>
-        <location filename="../codedownloader.cpp" line="37"/>
+        <location filename="../codedownloader.cpp" line="49"/>
         <source>Downloading...</source>
         <translation>Descargando...</translation>
     </message>
     <message>
-        <location filename="../codedownloader.cpp" line="58"/>
+        <location filename="../codedownloader.cpp" line="76"/>
         <source>Connecting to %1</source>
         <translation>Conectándose a %1</translation>
     </message>
     <message>
-        <location filename="../codedownloader.cpp" line="126"/>
-        <source>The Youtube code has been updated successfully.</source>
-        <translation>Actualizouse o código para YouTube.</translation>
+        <location filename="../codedownloader.cpp" line="145"/>
+        <source>The YouTube code has been installed successfully.</source>
+        <translation>O código de Youtube instalouse correctamente.</translation>
     </message>
     <message>
-        <location filename="../codedownloader.cpp" line="127"/>
+        <location filename="../codedownloader.cpp" line="146"/>
         <source>Installed version: %1</source>
         <translation>Versión instalada: %1</translation>
     </message>
     <message>
-        <location filename="../codedownloader.cpp" line="128"/>
+        <location filename="../codedownloader.cpp" line="147"/>
         <source>Success</source>
         <translation>Éxito</translation>
     </message>
     <message>
-        <location filename="../codedownloader.cpp" line="133"/>
-        <location filename="../codedownloader.cpp" line="138"/>
+        <location filename="../codedownloader.cpp" line="152"/>
+        <location filename="../codedownloader.cpp" line="157"/>
         <source>Error</source>
         <translation>Erro</translation>
     </message>
     <message>
-        <location filename="../codedownloader.cpp" line="133"/>
-        <source>An error happened writing %1</source>
-        <translation>Aconteceu un erro escribindo %1</translation>
+        <location filename="../codedownloader.cpp" line="152"/>
+        <source>It&apos;s not possible to save %1.</source>
+        <translation>Non é posíbel gardar %1.</translation>
     </message>
     <message>
-        <location filename="../codedownloader.cpp" line="138"/>
+        <location filename="../codedownloader.cpp" line="157"/>
         <source>An error happened while downloading the file:&lt;br&gt;%1</source>
         <translation>Aconteceu un erro mentres se descargaba: &lt;br&gt;%1</translation>
     </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="165"/>
+        <source>%1 failed to communicate with youtube-dl. Either it&apos;s not installed or it doesn&apos;t work correctly.</source>
+        <translation>%1 fallou tentando a comunicación co youtube-dl. Ou ben non está instalado ou non funciona correctamente.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="169"/>
+        <source>It wasn&apos;t possible to find the URL for this video.</source>
+        <translation>Non foi posíbel atopar a URL deste vídeo.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="170"/>
+        <source>Maybe you need to update youtube-dl.</source>
+        <translation>Quizais precise actualizar youtube-dl.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="175"/>
+        <source>In order to play YouTube videos, %1 needs an external application called youtube-dl.</source>
+        <translation>Con fin de reproducir vídeos de YouTube, %1 precisa dunha aplicación externa chamada youtube-dl.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="176"/>
+        <source>This component needs to be updated frequently.</source>
+        <translation>Este compoñente precisa actualizacións frecuentes.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="177"/>
+        <source>You can update it just by reinstalling SMPlayer. The installer will download and install the very latest version.</source>
+        <translation>Pode actualizalo simplemente reinstalando o SMPlayer. O instalador descargará e instalará a última versión.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="179"/>
+        <source>Install / Update YouTube support</source>
+        <translation>Instalar / Actualizar compatibilidade con YouTube</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="232"/>
+        <source>In order to play YouTube videos, %1 needs the help of an external application.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="233"/>
+        <source>%1 can download and install this application for you.</source>
+        <translation>%1 pode descargar e instalar esta aplicación por vostede.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="234"/>
+        <source>It will be downloaded from the official website and installed as %1.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="235"/>
+        <source>Would you like to proceed?</source>
+        <translation>Desexa continuar?</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="239"/>
+        <location filename="../codedownloader.cpp" line="242"/>
+        <source>Install YouTube support?</source>
+        <translation>Desexa instalar a compatibilidade con YouTube?</translation>
+    </message>
 </context>
 <context>
     <name>ConfigDialog</name>
@@ -301,17 +298,22 @@
         <translation>&amp;Xeral</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="108"/>
+        <location filename="../configdialog.ui" line="127"/>
+        <source>A&amp;dd...</source>
+        <translation>Enga&amp;dir...</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="178"/>
         <source>&amp;Players</source>
         <translation>&amp;Reprodutores</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="156"/>
+        <location filename="../configdialog.ui" line="226"/>
         <source>Add</source>
         <translation>Engadir</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="121"/>
+        <location filename="../configdialog.ui" line="191"/>
         <source>Up</source>
         <translation>Arriba</translation>
     </message>
@@ -326,37 +328,62 @@
         <translation>&amp;Calidade preferida:</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="167"/>
+        <location filename="../configdialog.ui" line="94"/>
+        <source>Sites</source>
+        <translation>Sitios</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="100"/>
+        <source>&amp;Site:</source>
+        <translation>&amp;Sitio:</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="120"/>
+        <source>Edi&amp;t...</source>
+        <translation>Edi&amp;tar...</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="138"/>
+        <source>De&amp;lete</source>
+        <translation>E&amp;liminar</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="152"/>
+        <source>YouTube support application</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="237"/>
         <source>Delete</source>
         <translation>Eliminar</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="191"/>
+        <location filename="../configdialog.ui" line="261"/>
         <source>Edit</source>
         <translation>Editar</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="204"/>
+        <location filename="../configdialog.ui" line="274"/>
         <source>A&amp;dd predefined players</source>
         <translation>Enga&amp;dir os reprodutores predefinidos</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="240"/>
+        <location filename="../configdialog.ui" line="310"/>
         <source>&amp;Interface</source>
         <translation>&amp;Interface</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="248"/>
+        <location filename="../configdialog.ui" line="318"/>
         <source>&amp;Style:</source>
         <translation>&amp;Estilo:</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="284"/>
+        <location filename="../configdialog.ui" line="354"/>
         <source>Font:</source>
         <translation>Tipo de letra:</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="298"/>
+        <location filename="../configdialog.ui" line="368"/>
         <source>C&amp;hange...</source>
         <translation>Ca&amp;mbiar...</translation>
     </message>
@@ -371,15 +398,25 @@
         <translation>Descargar os vídeos por medio dun servizo &amp;externo</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="132"/>
+        <location filename="../configdialog.ui" line="202"/>
         <source>Down</source>
         <translation>Abaixo</translation>
     </message>
     <message>
-        <location filename="../configdialog.cpp" line="81"/>
+        <location filename="../configdialog.cpp" line="82"/>
         <source>Default</source>
         <translation>Predeterminado</translation>
     </message>
+    <message>
+        <location filename="../configdialog.cpp" line="460"/>
+        <source>yt-dlp (based on youtube-dl with improvements)</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../configdialog.cpp" line="478"/>
+        <source>Other</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileChooser</name>
@@ -392,50 +429,59 @@
 <context>
     <name>MyWebView</name>
     <message>
-        <location filename="../mywebview.cpp" line="36"/>
-        <source>Open link in a web browser</source>
-        <translation>Abrir a ligazón nun navegador web</translation>
-    </message>
-    <message>
-        <location filename="../mywebview.cpp" line="52"/>
-        <source>Open link in new window</source>
-        <translation>Abrir a ligazón nunha nova xanela</translation>
-    </message>
-    <message>
-        <location filename="../mywebview.cpp" line="75"/>
-        <source>Open audio with</source>
-        <translation>Abrir o son con</translation>
-    </message>
-    <message>
-        <location filename="../mywebview.cpp" line="99"/>
-        <location filename="../mywebview.cpp" line="124"/>
-        <source>Open with %1</source>
-        <translation>Abrir con %1</translation>
-    </message>
-    <message>
-        <location filename="../mywebview.cpp" line="131"/>
-        <source>Open audio with %1</source>
-        <translation>Abrir o son con %1</translation>
-    </message>
-    <message>
-        <location filename="../mywebview.cpp" line="49"/>
-        <source>Copy link to clipboard</source>
-        <translation>Copiar a ligazón no portarretallos</translation>
+        <location filename="../mywebview.cpp" line="37"/>
+        <source>Open in &amp;YouTube</source>
+        <translation>Abrir no &amp;YouTube</translation>
     </message>
     <message>
         <location filename="../mywebview.cpp" line="48"/>
-        <source>Save link...</source>
-        <translation>Gardar a ligazón…</translation>
+        <source>&amp;Save link...</source>
+        <translation>&amp;Gardar a ligazón…</translation>
     </message>
     <message>
-        <location filename="../mywebview.cpp" line="50"/>
+        <location filename="../mywebview.cpp" line="51"/>
+        <source>Copy &amp;link to clipboard</source>
+        <translation>Copiar a &amp;ligazón ao portarretallos</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="52"/>
         <source>Open link in this window</source>
         <translation>Abrir a ligazón nesta xanela</translation>
     </message>
     <message>
-        <location filename="../mywebview.cpp" line="51"/>
-        <source>Copy text to clipboard</source>
-        <translation>Copiar o texto no portapapeis</translation>
+        <location filename="../mywebview.cpp" line="54"/>
+        <source>&amp;Copy text to clipboard</source>
+        <translation>&amp;Copiar texto ao portarretallos</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="55"/>
+        <source>Open link in &amp;new window</source>
+        <translation>Abrir a ligazón nunha &amp;nova xanela</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="79"/>
+        <source>&amp;Play with</source>
+        <translation>&amp;Reproducir con</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="84"/>
+        <source>Play &amp;audio with</source>
+        <translation>Reproducir o &amp;son con</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="137"/>
+        <source>&amp;Play with %1</source>
+        <translation>&amp;Reproducir con %1</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="145"/>
+        <source>Play &amp;audio with %1</source>
+        <translation>Reproducir o &amp;son con %1</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="154"/>
+        <source>Play video with a &amp;web browser</source>
+        <translation>Reproducir vídeo cun navegador &amp;web</translation>
     </message>
 </context>
 <context>
@@ -506,4 +552,40 @@
         <translation>Predeterminado</translation>
     </message>
 </context>
-</TS>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../version.cpp" line="48"/>
+        <source>%1 (revision %2) %3</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../version.cpp" line="50"/>
+        <source>%1 (revision %2)</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>SiteDialog</name>
+    <message>
+        <location filename="../sitedialog.ui" line="14"/>
+        <source>Edit Site</source>
+        <translation>Editar sitio</translation>
+    </message>
+    <message>
+        <location filename="../sitedialog.ui" line="22"/>
+        <source>&amp;Name:</source>
+        <translation>&amp;Nome:</translation>
+    </message>
+    <message>
+        <location filename="../sitedialog.ui" line="39"/>
+        <source>&amp;Home page URL:</source>
+        <translation>URL da páxin&amp;a de inicio:</translation>
+    </message>
+    <message>
+        <location filename="../sitedialog.ui" line="56"/>
+        <source>&amp;Search URL:</source>
+        <translation>URL de bu&amp;sca:</translation>
+    </message>
+</context>
+</TS>
\ No newline at end of file
